@@ -21,6 +21,25 @@ JapaneseColors(c("sangoiro","kuriiro"))
 
 
 
+cleanEx()
+nameEx("jholiday")
+### * jholiday
+
+flush(stderr()); flush(stdout())
+
+### Name: jholiday
+### Title: Calculate public holidays in Japan
+### Aliases: jholiday is.jholiday
+### Keywords: holiday Japan
+
+### ** Examples
+
+jholiday(2013)
+d <- as.Date(c("2000-09-22","2013-11-04", "1968-01-27"))
+is.jholiday(d)
+
+
+
 cleanEx()
 nameEx("jyear")
 ### * jyear
